@@ -14,7 +14,7 @@ GNU General Public License for more details.
 
 You should have received a copy of the GNU General Public License
 along with this program; if not, write to the Free Software
-Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 
 This file is available from http://sourceforge.net/projects/latex2rtf/
 */
@@ -1833,8 +1833,9 @@ static char *SaveEquationAsFile(const char *post_begin_document,
         fprintf(f, "%s\n.\\quad %s\n%s", pre, eq, post);  
         }
     } 
-/*    else if (strstr(pre, "equation"))
-        fprintf(f, "$$%s$$", eq);  removed WH 2014-01-17*/
+    else if (strstr(pre, "equation"))
+        /* fprintf(f, "$$%s$$", eq);  WH 2014-01-17*/
+        fprintf(f, "\\begin{displaymath}\n%s\n\\end{displaymath}", eq);  /* WH 2014-04-03*/
     else
         fprintf(f, "%s\n%s\n%s", pre, eq, post);
 
